###Supplementary material methods 2. Statistical Analyses
####López-García, Á., Jurado-Rivera, J.A., Bota, J., Cifre, J., Baraza, E. 
####Space and vine cultivar interact to determine the arbuscular mycorrhizal fungal community 
####composition. Journal of Fungi 2020.

set.seed(123)

#Loading data----
otu_table<-read.table("otu_table.txt", header=T)
taxa<-read.table("taxa_table.txt", header=T)
var<-read.table("var_table.txt", header=T)
dis_phylo<-read.table("otu_phylodist.txt", header=T)

#Loading packages----
library(vegan)
library(picante)
library(nlme)
library(labdsv)
library(shape)
library(ggplot2)
library(gstat)
library(sp)
library(maptools)

#Rarefaction analysis----
rarecurve(otu_table[which(var$Sample_type=="Soil"),])
rarecurve(otu_table[which(var$Sample_type=="Root"),])

#Percentage AMF families----
#Whole study
VT_sum<-colSums(otu_table)
Total<-sum(otu_table)

sum(VT_sum[which(taxa$Family=="Glomeraceae")])/Total
sum(VT_sum[which(taxa$Family=="Claroideoglomeraceae")])/Total
sum(VT_sum[which(taxa$Family=="Paraglomeraceae")])/Total
sum(VT_sum[which(taxa$Family=="Diversisporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Archaeosporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Acaulosporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Gigasporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Ambisporaceae")])/Total

#Percentage AMF families
#Soil samples
VT_sum<-colSums(otu_table[which(var$Sample_type=="Soil"),])
Total<-sum(otu_table[which(var$Sample_type=="Soil"),])

sum(VT_sum[which(taxa$Family=="Glomeraceae")])/Total
sum(VT_sum[which(taxa$Family=="Claroideoglomeraceae")])/Total
sum(VT_sum[which(taxa$Family=="Paraglomeraceae")])/Total
sum(VT_sum[which(taxa$Family=="Diversisporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Archaeosporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Acaulosporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Gigasporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Ambisporaceae")])/Total

#Percentage AMF families
#Root samples
VT_sum<-colSums(otu_table[which(var$Sample_type=="Root"),])
Total<-sum(otu_table[which(var$Sample_type=="Root"),])

sum(VT_sum[which(taxa$Family=="Glomeraceae")])/Total
sum(VT_sum[which(taxa$Family=="Claroideoglomeraceae")])/Total
sum(VT_sum[which(taxa$Family=="Paraglomeraceae")])/Total
sum(VT_sum[which(taxa$Family=="Diversisporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Archaeosporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Acaulosporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Gigasporaceae")])/Total
sum(VT_sum[which(taxa$Family=="Ambisporaceae")])/Total

#Hellinger transformation of otu_table----
otu_table_hell<-decostand(otu_table, method="hellinger")

#Indicator species analysis----
cultivar_n<-c(rep(1,16),rep(2,16)) #coding cultivars
summary(indval(otu_table_hell,cultivar_n))## A table with indicator VTs will appear for each treatment

sample_type_n<-c(1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2)# coding sample type
summary(indval(otu_table_hell,sample_type_n))## a table with indicator OTUs will appear for each treatment.

#PCNM spatial decomposition----
PCNM.vegan<-pcnm(dist(var[,c(5,6)]))
PCNM.v<-as.data.frame(PCNM.vegan$vectors) #extracting PCNM vectors

#PCNM selection via PERMANOVA
adonis(otu_table_hell ~ ., data=PCNM.v, perm=1e3, method="euclidean")

#Diversity indices----
S<-specnumber(otu_table) #Richness
H<- diversity(otu_table, index= "shannon")
Simpson <- diversity(otu_table, index= "simpson")

#LM model Richness
mod<-lm(S ~ Sample_type*Cultivar, data=var)
var.test(S ~ var$Sample_type) #checking heterogeneity of variances
mod<-gls(S ~ Sample_type*Cultivar, data=var,weights=varIdent(form= ~ 1 | Sample_type)) #implementing the model including VarIdent
summary(mod)
anova(mod)
plot(mod)

#LM model Shannon
var.test(H~ var$Sample_type)
mod<-gls(H ~ Sample_type*Cultivar, data=var,weights=varIdent(form= ~ 1 | Sample_type))
summary(mod)
anova(mod)
plot(mod)

#LM model Simpson
var.test(Simpson~ var$Sample_type)
mot<-gls(Simpson ~ Sample_type*Cultivar, data=var,weights=varIdent(form= ~ 1 | Sample_type))
summary(mot)
anova(mot)
plot(mot)

#Plotting
par(mfrow = c(1, 3))
boxplot(S ~ Tipo, data=var)
boxplot(H ~ Tipo, data=var)
boxplot(Simpson ~ Tipo, data=var)

#Phylogenetic dispersion, ses.mpd----
ses.mpd.result.r1 <- ses.mpd(otu_table_hell, dis_phylo, null.model = "independentswap", abundance.weighted = TRUE, runs = 999)
boxplot(ses.mpd.result.r1$mpd.obs.z ~ var$Sample_type)
boxplot(ses.mpd.result.r1$mpd.obs.z ~ var$Cultivar)

#Running lm model for ses.mpd
phylo_data<-ses.mpd.result.r1$mpd.obs.z #extract ses.mpd values
var.test(phylo_data ~ var$Sample_type)
mod<-gls(phylo_data ~ Sample_type*Cultivar, data=var,weights=varIdent(form= ~ 1 | Sample_type))
summary(mod)
anova(mod)
plot(mod)

#Checking differences respect to null communities
t.test(phylo_data[which(var$Sample_type=="Root")])
t.test(phylo_data[which(var$Sample_type=="Soil")])

#Plotting all together
par(mfrow = c(1, 4))
boxplot(S ~ Tipo, data=var)
boxplot(H ~ Tipo, data=var)
boxplot(Simpson ~ Tipo, data=var)
boxplot(ses.mpd.result.r1$mpd.obs.z ~ var$Sample_type, xlab="Sample type")

#Multivariate analyses----
#PERMANOVA----
adonis(otu_table_hell ~ Sample_type*Cultivar*PCNM.v$PCNM1, data=var, perm=1e3, method="euclidean")

#Checking multivariate dispersion differences across factor levels
anova(betadisper(vegdist(otu_table_hell),group=var$Sample_type))
anova(betadisper(vegdist(otu_table_hell),group=var$Cultivar))

#Partial PERMANOVAs (per factor levels)
#By cultivar type
adonis(otu_table_hell[which(var$Cultivar=="Callet"),] ~ PCNM.v$PCNM1[which(var$Cultivar=="Callet")]*var$Sample_type[which(var$Cultivar=="Callet")], perm=1e3, method="euclidean")
adonis(otu_table_hell[which(var$Cultivar=="Merlot"),] ~ PCNM.v$PCNM1[which(var$Cultivar=="Merlot")]*var$Sample_type[which(var$Cultivar=="Merlot")], perm=1e3, method="euclidean")

#Over and below PCNM1 Median value
quantile(PCNM.v$PCNM1)
adonis(otu_table_hell[which(PCNM.v$PCNM1>0.0361),] ~ var$Cultivar[which(PCNM.v$PCNM1>0.0361)]*var$Sample_type[which(PCNM.v$PCNM1>0.0361)], perm=1e3, method="euclidean")
adonis(otu_table_hell[which(PCNM.v$PCNM1<0.0361),] ~ var$Cultivar[which(PCNM.v$PCNM1<0.0361)]*var$Sample_type[which(PCNM.v$PCNM1<0.0361)], perm=1e3, method="euclidean")

#Checking differences in multivariate dispersion
anova(betadisper(vegdist(otu_table_hell[which(PCNM.v$PCNM1>0.0361),]),group=var[which(PCNM.v$PCNM1>0.0361),]$Cultivar))

#RDA ordination, constrained by PCNM1, sample type and cultivar----
PCNM.rda<-rda(otu_table_hell~as.matrix(PCNM.v$PCNM1)+as.matrix(var$Sample_type)+as.matrix(var$Cutivar))
anova(PCNM.rda, step=200, perm.max=9999)

#Plotting RDA
plot(PCNM.rda,type="n",xlab="Axis1 (27.6%)", ylab="Axis2 (5.6%)",axes = FALSE, cex.lab=0.6, font.lab=2)
axis(1,at=c(-1,-0.8,-0.6,-0.4,-0.2,0.2,0.4,0.6,0.8,1),tck=-0.01, cex.axis=0.6, pos=0)
axis(2,at=c(-1,-0.8,-0.6,-0.4,-0.2,0.2,0.4,0.6,0.8,1),tck=-0.01, cex.axis=0.6, las=2,pos=0)
points(PCNM.rda2, choices=c(1,2), pch=c(15,16)[as.factor(var$Cultivar)], lwd=1.5, col=c("darkolivegreen3","darkred")[as.factor(var$Sample_type)], cex=1.2)
sp.var<-scores(PCNM.rda2, choices=1:2, scaling=2,display="bp")## ES SAMPLES
Arrows(0,0,sp.var[1,1],sp.var[1,2],col="red",lwd=1.5,arr.type="triangle",arr.width=0.1,arr.length=0.2)

#Testing significance of partitions
PCNM.rda2<-rda(otu_table_hell~as.matrix(PCNM.v[,1])+Condition(as.matrix(var$Tipo)+as.matrix(var$Variedad)))
anova(PCNM.rda2, step=200, perm.max=9999)
PCNM.rda2<-rda(otu_table_hell~as.matrix(var$Tipo)+Condition(as.matrix(PCNM.v[,1])+as.matrix(var$Variedad)))
anova(PCNM.rda2, step=200, perm.max=9999)
PCNM.rda2<-rda(otu_table_hell~as.matrix(var$Variedad)+Condition(as.matrix(PCNM.v[,1])+as.matrix(var$Tipo)))
anova(PCNM.rda2, step=200, perm.max=9999)

#Plotting distribution of PCNM1----
#Adapted Script from: https://rstudio-pubs-static.s3.amazonaws.com/46259_d328295794034414944deea60552a942.html [2]
## 1. Create a grid from the values in your points dataframe
## first get the range in data
coords<-var[,c(5,6)]
x.coord<-coords$Coord_x
y.coord<-coords$Coord_y
pcnm1<-PCNM.v$PCNM1

sample <- data.frame(x.coord, y.coord, pcnm1)
x.range <- as.integer(range(x.coord))
y.range <- as.integer(range(y.coord))

##2. Create a grid with a slightly larger extent
plot(coords)
#use the locator to click 4 points beyond the extent of the plot and use those to set your x and y extents
locator(4)
x.range <- as.integer(c(0,107))
y.range <- as.integer(c(15,75))

#now expand your range to a grid with spacing that you'd like to use in your interpolation
#here we will use 1m grid cells:
grd <- expand.grid(x=seq(from=x.range[1], to=x.range[2], by=1), y=seq(from=y.range[1], to=y.range[2], by=1))

#set the reference system
coordinates(sample) = ~x.coord+y.coord
coordinates(grd) <- ~ x+y
gridded(grd) <- TRUE

## test it out - this is a good way of checking that your sample points are all well within your grid. If they are not, try some different values in you r x and y ranges:
plot(grd, cex=1.5)
points(coords, pch=1, col='red', cex=1)
title("Interpolation Grid and Sample Points")

#Interpolate [inverse distance weighted interpolation]
idw2<-idw(formula=pcnm1 ~ 1, locations = sample, newdata = grd, idp = 2.0)
plot(idw2)
points(coords, pch=16, col=c("red","green")[as.factor(var$Cultivar)], cex=1)
title("Interpolated PCNM1 in the study area")



